@@ -21,13 +21,13 @@
 #ifndef GO_FORMAT_H
 #define GO_FORMAT_H
 
+#include <goffice/goffice.h>
 #include <goffice/goffice-features.h>
 #include <goffice/utils/goffice-utils.h>
 #include <pango/pango-attributes.h>
-#include <goffice/cut-n-paste/pcre/pcreposix.h>
+#include <pango/pango-layout.h>
 #include <glib.h>
 
-#include <goffice/utils/goffice-utils.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -60,6 +60,9 @@ typedef struct {
 	gboolean date_has_days;
 	gboolean date_has_months;
 	int      fraction_denominator;
+	gboolean simplify_mantissa;
+	int	 exponent_step;
+	gboolean use_markup;
 } GOFormatDetails;
 
 struct _GOFormat {
@@ -97,9 +100,13 @@ void      go_format_unref		(GOFormat *fmt);
 #define   go_format_is_text(fmt)	((fmt)->family == GO_FORMAT_TEXT)
 #define   go_format_is_var_width(fmt)	((fmt)->is_var_width)
 
+void      go_format_value_gstring       (GOFormat const *format, GString *res,
+					 double val,
+					 int col_width,
+					 GODateConventions const *date_conv,
+					 gboolean unicode_minus);
 char	*go_format_value		(GOFormat const *fmt, double val);
-void	 go_format_value_gstring	(GOFormat const *format, GString *res, double val,
-					 int col_width, GODateConventions const *date_conv);
+
 gboolean go_format_eq			(GOFormat const *a, GOFormat const *b);
 GOFormat *go_format_inc_precision	(GOFormat const *fmt);
 GOFormat *go_format_dec_precision	(GOFormat const *fmt);
@@ -114,19 +121,50 @@ typedef struct {
 } GOFormatCurrency;
 
 /* Indexed by GOFormatFamily */
-extern char const * const * const go_format_builtins [];
-extern GOFormatCurrency     const go_format_currencies [];
+GO_VAR_DECL char const * const * const go_format_builtins [];
+GO_VAR_DECL GOFormatCurrency     const go_format_currencies [];
+
+/*************************************************************************/
+
+typedef int (*GOFormatMeasure) (const GString *str, PangoLayout *layout);
+int go_format_measure_zero (const GString *str, PangoLayout *layout);
+int go_format_measure_pango (const GString *str, PangoLayout *layout);
+int go_format_measure_strlen (const GString *str, PangoLayout *layout);
+
+void go_render_general  (PangoLayout *layout, GString *str,
+			 GOFormatMeasure measure,
+			 const GOFontMetrics *metrics,
+			 double val,
+			 int col_width,
+			 gboolean unicode_minus);
+#ifdef GOFFICE_WITH_LONG_DOUBLE
+void go_render_generall (PangoLayout *layout, GString *str,
+			 GOFormatMeasure measure,
+			 const GOFontMetrics *metrics,
+			 long double val,
+			 int col_width,
+			 gboolean unicode_minus);
+#endif
 
 /*************************************************************************/
 
 typedef struct {
 	int  right_optional, right_spaces, right_req, right_allowed;
-	int  left_spaces, left_req;
-	float scale;
+	int  left_optional, left_spaces, left_req;
+	double scale;
 	gboolean rendered;
 	gboolean decimal_separator_seen;
 	gboolean group_thousands;
 	gboolean has_fraction;
+	gboolean unicode_minus;
+
+	gboolean exponent_seen;
+
+	int exponent_digit_nbr;
+	gboolean exponent_show_sign;
+	gboolean exponent_lower_e;
+
+	gboolean use_markup;
 } GONumberFormat;
 
 void go_render_number (GString *result, double number, GONumberFormat const *info);
@@ -135,26 +173,21 @@ void go_render_numberl (GString *result, long double number, GONumberFormat cons
 #endif
 
 /* Locale support routines */
-void	       go_set_untranslated_bools (void);
-char const *   go_setlocale            (int category, char const *val);
-GString const *format_get_currency     (gboolean *precedes, gboolean *space_sep);
-gboolean       format_month_before_day (void);
-char           format_get_arg_sep      (void);
-char           format_get_col_sep      (void);
-char           format_get_row_sep      (void);
-GString const *format_get_thousand     (void);
-GString const *format_get_decimal      (void);
-char const *   format_boolean          (gboolean b);
+void	       go_set_untranslated_bools  (void);
+char const *   go_setlocale               (int category, char const *val);
+GString const *go_format_get_currency     (gboolean *precedes, gboolean *space_sep);
+gboolean       go_format_month_before_day (void);
+char           go_format_get_arg_sep      (void);
+char           go_format_get_col_sep      (void);
+char           go_format_get_row_sep      (void);
+GString const *go_format_get_thousand     (void);
+GString const *go_format_get_decimal      (void);
+char const *   go_format_boolean          (gboolean b);
 
-void number_format_init (void);
-void number_format_shutdown (void);
-void currency_date_format_init     (void);
-void currency_date_format_shutdown (void);
-
-extern char const * const day_short   [];
-extern char const * const day_long    [];
-extern char const * const month_short [];
-extern char const * const month_long  [];
+void go_number_format_init (void);
+void go_number_format_shutdown (void);
+void go_currency_date_format_init     (void);
+void go_currency_date_format_shutdown (void);
 
 G_END_DECLS
 
