@@ -31,7 +31,7 @@
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-math.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
 enum {
@@ -265,11 +265,23 @@ barcol_draw_rect (GogRenderer *rend, gboolean flip,
 	if (flip) {
 		x0 = gog_axis_map_to_view (x_map, rect->y);
 		x1 = gog_axis_map_to_view (x_map, rect->y + rect->h);
-		y0 = gog_axis_map_to_view (y_map, rect->x);
-		y1 = gog_axis_map_to_view (y_map, rect->x + rect->w);
+		if (gog_axis_map_finite (y_map, rect->x))
+			y0 = gog_axis_map_to_view (y_map, rect->x);
+		else
+			y0 = gog_axis_map_get_baseline (y_map);
+		if (gog_axis_map_finite (y_map, rect->x + rect->w))
+			y1 = gog_axis_map_to_view (y_map, rect->x + rect->w);
+		else
+			y1 = gog_axis_map_get_baseline (y_map);
 	} else {
-		x0 = gog_axis_map_to_view (x_map, rect->x);
-		x1 = gog_axis_map_to_view (x_map, rect->x + rect->w);
+		if (gog_axis_map_finite (x_map, rect->x))
+			x0 = gog_axis_map_to_view (x_map, rect->x);
+		else
+			x0 = gog_axis_map_get_baseline (x_map);
+		if (gog_axis_map_finite (x_map, rect->x + rect->w))
+			x1 = gog_axis_map_to_view (x_map, rect->x + rect->w);
+		else
+			x1 = gog_axis_map_get_baseline (x_map);
 		y0 = gog_axis_map_to_view (y_map, rect->y);
 		y1 = gog_axis_map_to_view (y_map, rect->y + rect->h);
 	}
@@ -467,8 +479,8 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 						paths[j][i * 2 - 1].x = gog_axis_map_to_view (x_map, x);
 						paths[j][i * 2 - 1].y = gog_axis_map_to_view (y_map, work.y);
 					}
-					paths[j][i].x = gog_axis_map_to_view (x_map, x);
-					paths[j][i].x = gog_axis_map_to_view (y_map, work.y + work.h);
+					paths[j][i * 2].x = gog_axis_map_to_view (x_map, x);
+					paths[j][i * 2].y = gog_axis_map_to_view (y_map, work.y + work.h);
 				}
 			}
 		}
@@ -495,23 +507,10 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 	gog_chart_map_free (chart_map);
 }
 
-static gboolean
-gog_barcol_view_info_at_point (GogView *view, double x, double y,
-			       GogObject const *cur_selection,
-			       GogObject **obj, char **name)
-{
-	if (obj != NULL)
-		*obj = view->model;
-	if (name != NULL)
-		*name = g_strdup (gog_object_get_name (GOG_OBJECT (view->model)));
-	return TRUE;
-}
-
 static void
 gog_barcol_view_class_init (GogViewClass *view_klass)
 {
 	view_klass->render	  = gog_barcol_view_render;
-	view_klass->info_at_point = gog_barcol_view_info_at_point;
 	view_klass->clip	  = TRUE;
 }
 
